import { Parser } from '../../infrastructure/parser';
export class XmlViewerComponent {
    componentDidLoad() {
    }
    toArray(obj) {
        let arr = [];
        for (let i = 0; i < obj.length; i++) {
            arr.push(obj[i]);
        }
        return arr;
    }
    prepareXml() {
        let xdoc = Parser.Parse(this.xml.trim());
        return xdoc;
    }
    renderAttribute(attribute) {
        return (h("span", null,
            "\u00A0",
            h("span", { class: "attr" },
                attribute.name,
                "=\"",
                h("span", { class: "attr-value" }, attribute.value),
                "\"")));
    }
    renderNodeValue(nodeValue) {
        if (!nodeValue) {
            return null;
        }
        if (nodeValue.length > 150) {
            return (h("ul", null,
                h("li", null, nodeValue)));
        }
        else {
            return (h("span", null, nodeValue));
        }
    }
    renderNode(node) {
        if (!node) {
            return null;
        }
        let children = this.toArray(node.children);
        let attributes = this.toArray(node.attributes);
        let nodeValue = node.firstChild ? node.firstChild.nodeValue : null;
        nodeValue = nodeValue ? nodeValue.trim() : null;
        return (h("ul", null,
            h("li", null,
                h("div", { class: "element" },
                    "<",
                    node.nodeName,
                    attributes.map(a => this.renderAttribute(a)),
                    ">"),
                h("div", { class: "element-content" }, this.renderNodeValue(nodeValue)),
                children.map(c => this.renderNode(c)),
                h("div", { class: "element" },
                    "</",
                    node.nodeName,
                    ">"))));
    }
    render() {
        if (this.xml === null || this.xml === undefined) {
            return null;
        }
        if (this.xml.length === 0) {
            return null;
        }
        let xdoc = null;
        try {
            xdoc = this.prepareXml();
        }
        catch (e) {
            console.log(e);
        }
        if (!xdoc || !xdoc.documentElement.childNodes) {
            return (h("code", null, this.xml));
        }
        return (h("p", null,
            h("code", null, this.renderNode(xdoc.documentElement))));
    }
    static get is() { return "xml-viewer-component"; }
    static get encapsulation() { return "shadow"; }
    static get properties() { return {
        "xml": {
            "type": String,
            "attr": "xml"
        }
    }; }
    static get style() { return "/**style-placeholder:xml-viewer-component:**/"; }
}
