import { h } from '../xmlviewercomponent.core.js';

class Parser {
    static Parse(xmlstr) {
        if (typeof DOMParser !== 'undefined') {
            let domDoc = (new DOMParser()).parseFromString(xmlstr, 'application/xml');
            if (domDoc.documentElement.nodeName == "parsererror") {
                throw new Error('XML parsing error');
            }
            return domDoc;
        }
        return null;
    }
}

class XmlViewerComponent {
    componentDidLoad() {
    }
    toArray(obj) {
        let arr = [];
        for (let i = 0; i < obj.length; i++) {
            arr.push(obj[i]);
        }
        return arr;
    }
    prepareXml() {
        let xdoc = Parser.Parse(this.xml.trim());
        return xdoc;
    }
    renderAttribute(attribute) {
        return (h("span", null,
            "\u00A0",
            h("span", { class: "attr" },
                attribute.name,
                "=\"",
                h("span", { class: "attr-value" }, attribute.value),
                "\"")));
    }
    renderNodeValue(nodeValue) {
        if (!nodeValue) {
            return null;
        }
        if (nodeValue.length > 150) {
            return (h("ul", null,
                h("li", null, nodeValue)));
        }
        else {
            return (h("span", null, nodeValue));
        }
    }
    renderNode(node) {
        if (!node) {
            return null;
        }
        let children = this.toArray(node.children);
        let attributes = this.toArray(node.attributes);
        let nodeValue = node.firstChild ? node.firstChild.nodeValue : null;
        nodeValue = nodeValue ? nodeValue.trim() : null;
        return (h("ul", null,
            h("li", null,
                h("div", { class: "element" },
                    "<",
                    node.nodeName,
                    attributes.map(a => this.renderAttribute(a)),
                    ">"),
                h("div", { class: "element-content" }, this.renderNodeValue(nodeValue)),
                children.map(c => this.renderNode(c)),
                h("div", { class: "element" },
                    "</",
                    node.nodeName,
                    ">"))));
    }
    render() {
        if (this.xml === null || this.xml === undefined) {
            return null;
        }
        if (this.xml.length === 0) {
            return null;
        }
        let xdoc = null;
        try {
            xdoc = this.prepareXml();
        }
        catch (e) {
            console.log(e);
        }
        if (!xdoc || !xdoc.documentElement.childNodes) {
            return (h("code", null, this.xml));
        }
        return (h("p", null,
            h("code", null, this.renderNode(xdoc.documentElement))));
    }
    static get is() { return "xml-viewer-component"; }
    static get encapsulation() { return "shadow"; }
    static get properties() { return {
        "xml": {
            "type": String,
            "attr": "xml"
        }
    }; }
    static get style() { return "code.sc-xml-viewer-component{margin:.1rem .25rem 1rem .25rem;padding:0;color:#767676;font-family:monospace,monospace;text-shadow:0 1px #fff;direction:ltr;text-align:left;word-spacing:normal;word-break:normal;word-wrap:normal;line-height:1.2;-moz-tab-size:2;-o-tab-size:2;tab-size:2;-webkit-hyphens:none;-moz-hyphens:none;-ms-hyphens:none;hyphens:none}code.sc-xml-viewer-component   ul.sc-xml-viewer-component{list-style-type:none;margin:0;padding-left:1rem}code.sc-xml-viewer-component   div.element.sc-xml-viewer-component{font-weight:700;color:#8b0000;display:inline-block}code.sc-xml-viewer-component   div.element-content.sc-xml-viewer-component{font-weight:400;display:inline-block}code.sc-xml-viewer-component   span.attr.sc-xml-viewer-component{font-weight:700;color:#535353}code.sc-xml-viewer-component   span.attr-value.sc-xml-viewer-component{font-weight:400}code.sc-xml-viewer-component   div.comment.sc-xml-viewer-component{color:#006400}"; }
}

export { XmlViewerComponent };
